splearn.tests package
=====================

Submodules
----------

splearn.tests.test\_automaton module
------------------------------------

.. automodule:: splearn.tests.test_automaton
    :members:
    :undoc-members:
    :show-inheritance:

splearn.tests.test\_base module
-------------------------------

.. automodule:: splearn.tests.test_base
    :members:
    :undoc-members:
    :show-inheritance:

splearn.tests.test\_data\_sample module
---------------------------------------

.. automodule:: splearn.tests.test_data_sample
    :members:
    :undoc-members:
    :show-inheritance:

splearn.tests.test\_hankel module
---------------------------------

.. automodule:: splearn.tests.test_hankel
    :members:
    :undoc-members:
    :show-inheritance:

splearn.tests.test\_serializer module
-------------------------------------

.. automodule:: splearn.tests.test_serializer
    :members:
    :undoc-members:
    :show-inheritance:

splearn.tests.test\_spectral module
-----------------------------------

.. automodule:: splearn.tests.test_spectral
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: splearn.tests
    :members:
    :undoc-members:
    :show-inheritance:
